@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::Conflicts;
 {
-  $Dist::Zilla::Plugin::Conflicts::VERSION = '0.11';
+  $Dist::Zilla::Plugin::Conflicts::VERSION = '0.12';
 }
 BEGIN {
   $Dist::Zilla::Plugin::Conflicts::AUTHORITY = 'cpan:DROLSKY';
@@ -97,16 +97,6 @@ sub register_prereqs {
         { phase => 'runtime' },
         'Dist::CheckConflicts' => '0.02',
     );
-
-    for my $phase (qw( develop runtime )) {
-        $self->zilla->register_prereqs(
-            {
-                phase => $phase,
-                type  => 'conflicts',
-            },
-            %{ $self->_conflicts() },
-        );
-    }
 }
 
 sub gather_files {
@@ -370,7 +360,7 @@ Dist::Zilla::Plugin::Conflicts - Declare conflicts for your distro
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -398,8 +388,8 @@ L<Dist::CheckConflicts>.
 Second, it adds code to your F<Makefile.PL> or F<Build.PL> to load the
 generated module and print warnings if conflicts are detected.
 
-Third, it adds "conflicts" entries to the develop and runtime prereqs, per
-CPAN Meta Spec (https://metacpan.org/module/CPAN::Meta::Spec#Prereq-Spec).
+Third, it adds "conflicts" entries to the develop and runtime prereqs, per the
+L<CPAN Meta Spec|https://metacpan.org/module/CPAN::Meta::Spec#Prereq-Spec>.
 
 Finally, it adds the conflicts to the F<META.json> and/or F<META.yml> files
 under the "x_breaks" key.
